django_analyses.models.pipeline package — django_analyses 0.0.3 documentation

# django_analyses.models.pipeline package

## Submodules

## django_analyses.models.pipeline.node module

class `django_analyses.models.pipeline.node.` `Node`(id, created, modified, analysis_version, configuration)

  Bases: `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `analysis_version`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `analysis_version_id`
  `check_configuration_sameness`(key: str, value) → bool
  `check_run_configuration_sameness`(run: django_analyses.models.run.Run) → bool
  `configuration`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `get_full_configuration`(inputs: dict) → dict
  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `get_required_nodes`() → django.db.models.query.QuerySet
  `get_requiring_nodes`() → django.db.models.query.QuerySet
  `get_run_set`() → django.db.models.query.QuerySet
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `objects` = <django.db.models.manager.Manager object>
  `pipe_destination_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `pipe_source_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  property `required_nodes`
  property `requiring_nodes`
  `run`(inputs: dict, user: django.contrib.auth.models.User = None) → django_analyses.models.run.Run
  property `run_set`
  `save`(*args, **kwargs)

    Save the current instance. Override this in a subclass if you want to control the saving process.

    The ‘force_insert’ and ‘force_update’ parameters can be used to insist that the “save” must be an SQL insert or update (or equivalent for non-SQL backends), respectively. Normally, they should not be set.

  `validate`() → None

## django_analyses.models.pipeline.pipe module

class `django_analyses.models.pipeline.pipe.` `Pipe`(id, pipeline, source, base_source_port, destination, base_destination_port)

  Bases: `django.db.models.base.Model`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `base_destination_port`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `base_destination_port_id`
  `base_source_port`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `base_source_port_id`
  `destination`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `destination_id`
  property `destination_port`
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  `objects` = <django.db.models.manager.Manager object>
  `pipeline`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `pipeline_id`
  `source`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `source_id`
  property `source_port`

## django_analyses.models.pipeline.pipeline module

class `django_analyses.models.pipeline.pipeline.` `Pipeline`(id, created, modified, title, description)

  Bases: `django_extensions.db.models.TitleDescriptionModel`, `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  property `entry_nodes`
  `get_entry_nodes`() → django_analyses.models.pipeline.node.Node
  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_node_set`() → django.db.models.query.QuerySet
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `node_set`
  `objects` = <django.db.models.manager.Manager object>
  `pipe_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

## Module contents